GraphStorage

Enum GraphStorage 

pub enum GraphStorage {
    Mem(LockedGraph),
    Unlocked(Arc<TemporalGraph>),
}

Variants

Implementations

Source

impl GraphStorage

pub fn ptr_eq(&self, other: &Self) -> bool

Check if two storage instances point at the same underlying storage

pub fn mutable(&self) -> Result<&Arc<TemporalGraph>, MutationError>

pub fn is_immutable(&self) -> bool

pub fn lock(&self) -> Self

pub fn nodes(&self) -> NodesStorageEntry<'_>

pub fn internalise_node(&self, v: NodeRef<'_>) -> Option<VID>

pub fn unfiltered_num_nodes(&self) -> usize

pub fn unfiltered_num_edges(&self) -> usize

pub fn unfiltered_num_layers(&self) -> usize

pub fn core_nodes(&self) -> NodesStorage

pub fn core_node<'a>(&'a self, vid: VID) -> NodeStorageEntry<'a>

pub fn try_core_node<'a>(&'a self, vid: VID) -> Option<NodeStorageEntry<'a>>

Try to get a node that may not be initialised yet

pub fn edges(&self) -> EdgesStorageRef<'_>

pub fn owned_edges(&self) -> EdgesStorage

pub fn edge_entry(&self, eid: EID) -> EdgeStorageEntry<'_>

pub fn layer_ids_iter( &self, layer_ids: &LayerIds, ) -> impl Iterator<Item = usize>

pub fn node_meta(&self) -> &Meta

pub fn edge_meta(&self) -> &Meta

pub fn graph_meta(&self) -> &GraphMeta