Trait InternalLayerOps

pub trait InternalLayerOps: CoreGraphOps {
    // Required method
    fn layer_ids(&self) -> &LayerIds;

    // Provided methods
    fn layer_ids_from_names(&self, key: Layer) -> Result<LayerIds, InvalidLayer> { ... }
    fn valid_layer_ids_from_names(&self, key: Layer) -> LayerIds { ... }
}

Required Methods

fn layer_ids(&self) -> &LayerIds

get the layer ids for the graph view

Provided Methods

fn layer_ids_from_names(&self, key: Layer) -> Result<LayerIds, InvalidLayer>

Get the layer id for the given layer name

fn valid_layer_ids_from_names(&self, key: Layer) -> LayerIds

Get the valid layer ids for given layer names

Implementors