Module core_ops

Traits

CoreGraphOps
Core functions that should (almost-)always be implemented by pointing at the underlying graph.
InheritCoreGraphOps

Functions

is_view_compatible
Check if two Graph views point at the same underlying storage